@@ -1,10 +1,12 @@
 from __future__ import annotations
 
 from dataclasses import dataclass, fields
-from typing import Type, Generator, get_type_hints, get_args, Dict
+from typing import Type, Generator, get_type_hints, get_args, Dict, List
 
 from google.cloud import datastore
 
+from gcp_pilot import exceptions
+
 
 class ClientMixin:
     _client = None
@@ -29,7 +31,7 @@ class MultipleObjectsFound(Exception):
 
 
 operators = {
-    'eq': '==',
+    'eq': '=',
     'gt': '>',
     'gte': '>=',
     'lt': '<',
@@ -38,17 +40,25 @@ operators = {
 }
 
 
-def query_operator(key: str) -> tuple:
+def query_operator(key: str, accepted_fields: List[str]) -> tuple:
+    lookup_fields = []
+    operator = None
+
     parts = key.split('__')
-    field = parts[0]
-    if len(parts) == 1:
-        operator = '=='
-    else:
-        try:
-            operator = operators[parts[1]]
-        except KeyError as e:
-            raise Exception(f"Unsupported query operator {parts[1]}") from e
-    return field, operator
+    for idx, part in enumerate(parts):
+        is_last = idx == len(parts) - 1
+        if part in operators:
+            if not is_last:
+                raise exceptions.UnsupportedFormatException(f"Unsupported lookup key format {key}")
+            operator = part
+        elif idx == 0 and part not in accepted_fields:
+            raise exceptions.ValidationError(
+                f"{part} is not a valid field. Excepted one of {' | '.join(accepted_fields)}"
+            )
+        else:
+            lookup_fields.append(part)
+
+    return '.'.join(lookup_fields), (operator or '=')
 
 
 @dataclass
@@ -155,7 +165,7 @@ class Document(ClientMixin, EmbeddedDocument):
         query = cls._get_client().query(kind=cls._kind())
 
         for key, value in kwargs.items():
-            field, operator = query_operator(key=key)
+            field, operator = query_operator(key=key, accepted_fields=list(cls._fields().keys()))
             query.add_filter(field, operator, value)
 
         for entity in query.fetch():
@@ -167,14 +177,16 @@ class Document(ClientMixin, EmbeddedDocument):
             entity = cls._get_client().get(key=cls._get_key(pk=pk))
             if entity:
                 return cls._from_dict(**cls.from_entity(entity=entity))
-        else:
-            one_obj = None
-            for obj in cls.list(**kwargs):
-                if one_obj is not None:
-                    raise MultipleObjectsFound(cls, filters=kwargs)
-                one_obj = obj
-            return one_obj
-        raise DoesNotExist(cls, pk)
+            raise DoesNotExist(cls, pk)
+
+        one_obj = None
+        for obj in cls.list(**kwargs):
+            if one_obj is not None:
+                raise MultipleObjectsFound(cls, filters=kwargs)
+            one_obj = obj
+        if not one_obj:
+            raise DoesNotExist(cls, pk)
+        return one_obj
 
     def to_entity(self) -> datastore.Entity:
         if not self.pk:
